@@ -101,7 +101,7 @@ void MainWindow::initialize()
     // load Settings
     loadSettings();
     qDebug() << "settings loaded";
-    refreshAll();
+    refreshAll(true);
 
     // GPS
     m_gps = QGeoPositionInfoSource::createDefaultSource(this);
@@ -262,10 +262,10 @@ void MainWindow::loadSettings() {
         changed = true;
         Core::model()->clearAll();
         Core::engine()->setLocation(location);
-        Core::map()->setBusinessArea(Core::engine()->businessArea());
     }
 
     if(changed) {
+        Core::map()->setBusinessArea(Core::engine()->businessArea());
         qDebug() << "centering!";
         centerOnStartCoordinates();
     }
